@@ -24,7 +24,6 @@
 #include <QFileDialog>
 #include <QScrollBar>
 #include <QTemporaryDir>
-#include <QTextStream>
 
 #include "about.h"
 #include "unistd.h"
@@ -38,10 +37,9 @@ MainWindow::MainWindow(const QStringList& args) :
 
     // setup options
     LUM.clear();
-    QFileInfo settingsfile("/etc/live-usb-maker-gui-antix/live-usb-maker-gui-antix.conf");
-    QSettings settings("/etc/live-usb-maker-gui-antix/live-usb-maker-gui-antix.conf", QSettings::NativeFormat);
+    QSettings settings("/etc/live-usb-maker-gui-antix/live-usb-maker-gui-antix.conf");
     LUM = settings.value("LUM", "live-usb-maker").toString();
-    size_check = settings.value("SizeCheck", 128).toInt();
+    size_check = settings.value("SizeCheck", 128).toUInt(); // in GB
     qDebug() << "LUM is:" << LUM;
 
     setWindowFlags(Qt::Window); // for the close, min and max buttons
@@ -66,7 +64,7 @@ MainWindow::~MainWindow()
 
 bool MainWindow::checkDestSize()
 {
-    int disk_size = cmd.getCmdOut("echo $(( $(sudo blockdev --getsize64 /dev/"+ device + ") / 1024**3 ))").toInt();
+    quint64 disk_size = cmd.getCmdOut("blockdev --getsize64 /dev/" + device).toULongLong() / (1024 * 1024 * 1024);
 
     if (disk_size > size_check) { // question when writing on large drives (potentially unintended)
         return (QMessageBox::Yes == QMessageBox::question(
@@ -80,7 +78,7 @@ bool MainWindow::checkDestSize()
 bool MainWindow::isRunningLive()
 {
     QString test = cmd.getCmdOut("df -T / |tail -n1 |awk '{print $2}'");
-    return ( test == "aufs" || test == "overlay" );
+    return (test == "aufs" || test == "overlay");
 }
 
 // determine if it's running in "toram" mode
@@ -94,17 +92,15 @@ void MainWindow::makeUsb(const QString &options)
     device = ui->combo_Usb->currentText().split(" ").at(0);
 
     QString source;
+    QString source_size;
     if (!ui->cb_clone_live->isChecked() && !ui->cb_clone_mode->isChecked()) {
         source = "\"" + ui->buttonSelectSource->property("filename").toString() + "\"";
-        QString source_size = cmd.getCmdOut("du -m \"" + ui->buttonSelectSource->property("filename").toString() + "\" 2>/dev/null | cut -f1", true);
-        iso_sectors = source_size.toInt() * 1024 / 512 * 1024;
+        source_size = cmd.getCmdOut("du -m \"" + ui->buttonSelectSource->property("filename").toString() + "\" 2>/dev/null |cut -f1", true);
     } else if (ui->cb_clone_mode->isChecked()) {
-        QString source_size = cmd.getCmdOut("du -m --summarize \"" + ui->buttonSelectSource->property("filename").toString() + "\" 2>/dev/null | cut -f1", true);
-        iso_sectors = source_size.toInt() * 1024 / 512 * 1024;
+        source_size = cmd.getCmdOut("du -m --summarize \"" + ui->buttonSelectSource->property("filename").toString() + "\" 2>/dev/null |cut -f1", true);
         source = "clone=\"" + ui->buttonSelectSource->property("filename").toString() + "\"";
-
         // check if source and destination are on the same drive
-        QString root_partition = cmd.getCmdOut("df --output=source \"" + ui->buttonSelectSource->property("filename").toString() + "\"| awk 'END{print $1}'");
+        QString root_partition = cmd.getCmdOut("df --output=source \"" + ui->buttonSelectSource->property("filename").toString() + "\" |awk 'END{print $1}'");
         if ("/dev/" + device == cmd.getCmdOut(cli_utils + "get_drive " + root_partition)) {
             QMessageBox::critical(this, tr("Failure"), tr("Source and destination are on the same device, please select again."));
             ui->stackedWidget->setCurrentWidget(ui->selectionPage);
@@ -114,11 +110,13 @@ void MainWindow::makeUsb(const QString &options)
         }
     } else if (ui->cb_clone_live->isChecked()) {
         source = "clone";
-        QString source_size = cmd.getCmdOut("du -m --summarize /live/boot-dev 2>/dev/null | cut -f1", true);
-        iso_sectors = source_size.toInt() * 1024 / 512 * 1024;
+        if (isToRam())
+            source_size = cmd.getCmdOut("du -m --summarize /live/to-ram 2>/dev/null |cut -f1", true);
+        else
+            source_size = cmd.getCmdOut("du -m --summarize /live/boot-dev 2>/dev/null |cut -f1", true);
     }
 
-    if(!checkDestSize()) {
+    if (!checkDestSize()) {
         ui->stackedWidget->setCurrentWidget(ui->selectionPage);
         ui->buttonNext->setEnabled(true);
         setCursor(QCursor(Qt::ArrowCursor));
@@ -126,9 +124,10 @@ void MainWindow::makeUsb(const QString &options)
     }
 
     // check amount of io on device before copy, this is in sectors
-    start_io = cmd.getCmdOut("cat /sys/block/" + device + "/stat |awk '{print $7}'", true).toInt();
+    int start_io = cmd.getCmdOut("cat /sys/block/" + device + "/stat |awk '{print $7}'", true).toInt();
     ui->progressBar->setMinimum(start_io);
     qDebug() << "start io is " << start_io;
+    int iso_sectors = source_size.toInt() * 2048; // source_size * 1024 / 512 * 1024
     ui->progressBar->setMaximum(iso_sectors + start_io);
     qDebug() << "max progress bar is " << ui->progressBar->maximum();
 
@@ -168,11 +167,11 @@ void MainWindow::setup()
     QValidator *validator = new QRegularExpressionValidator(rx, this);
     ui->edit_label->setValidator(validator);
 
-    //set save boot directory option to disable unless update mode is checked
+    // set save boot directory option to disable unless update mode is checked
     ui->cb_save_boot->setEnabled(false);
 
-    //check if running live or with "toram"
-    ui->cb_clone_live->setEnabled(isRunningLive() && !isToRam());
+    // check if running live
+    ui->cb_clone_live->setEnabled(isRunningLive());
 
     //check if datafirst option is available
     if (!cmd.run("live-usb-maker --help | grep -q data-first", true)) {
@@ -218,10 +217,6 @@ QString MainWindow::buildOptionList()
         options += "--force=makefs ";
     if (ui->cb_force_nofuse->isChecked())
         options += "--force=nofuse ";
-    if (ui->rb_dd->isChecked()) {
-
-    }
-
     if (ui->cb_data_first->isChecked())
         options += "--data-first=" + ui->spinBoxDataSize->cleanText() + "," + ui->comboBoxDataFormat->currentText() + " ";
 
@@ -241,7 +236,7 @@ void MainWindow::cleanup()
 {
     QFileInfo lum(LUM);
     QFileInfo logfile("/tmp/" + lum.baseName() + ".log");
-    if ( logfile.exists() ) {
+    if (logfile.exists()) {
         QString removecmd = "rm -f " + logfile.absoluteFilePath();
         system(removecmd.toUtf8());
     }
@@ -361,10 +356,6 @@ void MainWindow::on_buttonNext_clicked()
         ui->buttonNext->setEnabled(false);
         ui->stackedWidget->setCurrentWidget(ui->outputPage);
         makeUsb(buildOptionList());
-    } else if (ui->stackedWidget->currentWidget() == ui->outputPage) {
-
-    } else {
-        qApp->quit();
     }
 }
 
@@ -418,7 +409,7 @@ void MainWindow::on_buttonSelectSource_clicked()
         }
     } else if (ui->cb_clone_mode->isChecked()) {
         selected = QFileDialog::getExistingDirectory(this, tr("Select Source Directory"), QString(QDir::rootPath()), QFileDialog::ShowDirsOnly);
-        if (QFileInfo::exists(selected + "/antiX/linuxfs")|| QFileInfo::exists(selected + "/linuxfs")) {
+        if (QFileInfo::exists(selected + "/antiX/linuxfs") || QFileInfo::exists(selected + "/linuxfs")) {
             ui->buttonSelectSource->setText(selected);
             ui->buttonSelectSource->setProperty("filename", selected);
         } else {
@@ -484,7 +475,7 @@ void MainWindow::on_cb_update_clicked(bool checked)
 
 void MainWindow::on_cb_clone_mode_clicked(bool checked)
 {
-     if (checked) {
+    if (checked) {
         ui->buttonSelectSource->setStyleSheet("text-align: center;");
         ui->cb_clone_live->setChecked(false);
         on_cb_clone_live_clicked(false);
@@ -497,7 +488,7 @@ void MainWindow::on_cb_clone_mode_clicked(bool checked)
         ui->buttonSelectSource->setIcon(QIcon::fromTheme("user-home"));
         ui->cb_clone_live->setEnabled(isRunningLive());
     }
-     ui->buttonSelectSource->setProperty("filename", "");
+    ui->buttonSelectSource->setProperty("filename", "");
 }
 
 void MainWindow::on_cb_clone_live_clicked(bool checked)
@@ -531,9 +522,8 @@ void MainWindow::on_rb_dd_clicked()
     ui->cb_clone_mode->setEnabled(false);
     ui->cb_encrypt->setEnabled(false);
     ui->cb_pretend->setEnabled(false);
-    if (ui->groupAdvOptions->isVisible()) {
+    if (ui->groupAdvOptions->isVisible())
         on_buttonOptions_clicked();
-    }
     ui->buttonOptions->setEnabled(false);
     ui->label_percent->setEnabled(false);
     ui->label_part_label->setEnabled(false);
